@@ -1,17 +1,19 @@
 from bluer_options import string
 
+from bluer_algo import env
+
 
 class Specs:
     def __init__(
         self,
         tao: int = 1,
-        tac: int = 0,
+        tac: int = 1,
         tro: int = 3,
         trc: int = 1,
-        ta1: int = 30,
-        ta2: int = 30,
-        tr1: int = 24,
-        tr2: int = 36,
+        ta1: int = env.BLUER_AI_BPS_LOOP_BEACON_LENGTH_MIN,
+        ta2: int = env.BLUER_AI_BPS_LOOP_BEACON_LENGTH_MAX,
+        tr1: int = env.BLUER_AI_BPS_LOOP_RECEIVER_LENGTH_MIN,
+        tr2: int = env.BLUER_AI_BPS_LOOP_RECEIVER_LENGTH_MAX,
     ):
         self.tao = tao
         self.tac = tac
