@@ -1,6 +1,8 @@
 from typing import List
 
-from bluer_options.terminal import show_usage, xtra
+from bluer_options.terminal import show_usage
+
+from bluer_algo import env
 
 
 def help_timing(
@@ -11,11 +13,12 @@ def help_timing(
 
     args = [
         "[--length <1200>]",
+        "[--anchors <4>]",
         "[--nodes <3>]",
-        "[--ta1 <30>]",
-        "[--ta2 <30>]",
-        "[--tr1 <24>]",
-        "[--tr2 <36>]",
+        f"[--ta1 <{env.BLUER_AI_BPS_LOOP_BEACON_LENGTH_MIN:d}>]",
+        f"[--ta2 <{env.BLUER_AI_BPS_LOOP_BEACON_LENGTH_MAX:d}>]",
+        f"[--tr1 <{env.BLUER_AI_BPS_LOOP_RECEIVER_LENGTH_MIN:d}>]",
+        f"[--tr2 <{env.BLUER_AI_BPS_LOOP_RECEIVER_LENGTH_MAX:d}>]",
         "[--verbose 1]",
     ]
 
